@@ -8,11 +8,15 @@ This tool provides MCP integration for AutoMagik Spark API, enabling:
 - Source configuration for multiple AutoMagik instances
 """
 
-from typing import Dict, Any, Optional, List
+from typing import Dict, Any, Optional
 from fastmcp import FastMCP, Context
 from .config import SparkConfig
 from .client import SparkClient
-from .models import ScheduleType, TaskStatus, SourceType
+from .models import (
+    ScheduleType as ScheduleType,
+    TaskStatus as TaskStatus,
+    SourceType as SourceType,
+)
 import json
 
 # Global config and client instances
@@ -43,7 +47,7 @@ def get_metadata() -> Dict[str, Any]:
     """Return tool metadata for discovery"""
     return {
         "name": "spark",
-        "version": "1.0.0",
+        "version": "0.9.7",
         "description": "AutoMagik Spark workflow orchestration and AI agent management",
         "author": "Namastex Labs",
         "category": "workflow",
@@ -69,7 +73,7 @@ def create_server(tool_config: Optional[SparkConfig] = None):
 async def get_health(ctx: Optional[Context] = None) -> str:
     """
     Get health status of Spark API and its services.
-    
+
     Returns the status of API, worker, and Redis services.
     """
     global client
@@ -94,11 +98,11 @@ async def list_workflows(
 ) -> str:
     """
     List all synchronized workflows (agents, teams, structured workflows).
-    
+
     Args:
         source: Filter by source URL (optional)
         limit: Maximum number of workflows to return (default: 100)
-    
+
     Returns a list of workflows with their details including type, status, and run statistics.
     """
     global client
@@ -118,10 +122,10 @@ async def list_workflows(
 async def get_workflow(workflow_id: str, ctx: Optional[Context] = None) -> str:
     """
     Get detailed information about a specific workflow.
-    
+
     Args:
         workflow_id: The UUID of the workflow
-    
+
     Returns workflow details including configuration, components, and execution history.
     """
     global client
@@ -143,13 +147,13 @@ async def run_workflow(
 ) -> str:
     """
     Execute a workflow with the provided input.
-    
+
     Args:
         workflow_id: The UUID of the workflow to execute
         input_text: Input text for the workflow (e.g., question, task description)
-    
+
     Returns task execution details including output and status.
-    
+
     Examples:
         - For agents: "What is the capital of France?"
         - For teams: "Create a REST API with authentication"
@@ -172,10 +176,10 @@ async def run_workflow(
 async def delete_workflow(workflow_id: str, ctx: Optional[Context] = None) -> str:
     """
     Delete a synchronized workflow.
-    
+
     Args:
         workflow_id: The UUID of the workflow to delete
-    
+
     Returns confirmation of deletion.
     """
     global client
@@ -183,7 +187,7 @@ async def delete_workflow(workflow_id: str, ctx: Optional[Context] = None) -> st
         raise ValueError("Tool not configured")
 
     try:
-        result = await client.delete_workflow(workflow_id)
+        await client.delete_workflow(workflow_id)
         return json.dumps({"success": True, "deleted": workflow_id})
     except Exception as e:
         if ctx:
@@ -194,14 +198,15 @@ async def delete_workflow(workflow_id: str, ctx: Optional[Context] = None) -> st
 # Remote Workflow Discovery Tools
 @mcp.tool()
 async def list_remote_workflows(
-    source_url: str, ctx: Optional[Context] = None
+    source_url: str, simplified: bool = True, ctx: Optional[Context] = None
 ) -> str:
     """
     List available workflows from a remote AutoMagik instance.
-    
+
     Args:
         source_url: The URL of the remote AutoMagik instance (e.g., http://localhost:8881)
-    
+        simplified: Return only essential flow information (default: True)
+
     Returns a list of available workflows that can be synced.
     """
     global client
@@ -209,7 +214,7 @@ async def list_remote_workflows(
         raise ValueError("Tool not configured")
 
     try:
-        workflows = await client.list_remote_workflows(source_url)
+        workflows = await client.list_remote_workflows(source_url, simplified)
         return json.dumps(workflows, indent=2)
     except Exception as e:
         if ctx:
@@ -217,21 +222,49 @@ async def list_remote_workflows(
         raise
 
 
+@mcp.tool()
+async def get_remote_workflow(
+    workflow_id: str, source_url: str, ctx: Optional[Context] = None
+) -> str:
+    """
+    Get detailed information about a specific remote workflow.
+
+    Args:
+        workflow_id: The ID of the remote workflow
+        source_url: The URL of the remote AutoMagik instance (e.g., http://localhost:8881)
+
+    Returns detailed remote workflow information.
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        workflow = await client.get_remote_workflow(workflow_id, source_url)
+        return json.dumps(workflow, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to get remote workflow: {str(e)}")
+        raise
+
+
 @mcp.tool()
 async def sync_workflow(
     workflow_id: str,
+    source_url: str,
     input_component: str = "input",
     output_component: str = "output",
     ctx: Optional[Context] = None,
 ) -> str:
     """
     Sync a workflow from a remote source to local Spark instance.
-    
+
     Args:
         workflow_id: The ID of the workflow to sync
+        source_url: The URL of the remote source (e.g., http://localhost:8881)
         input_component: Input component name (default: "input")
         output_component: Output component name (default: "output")
-    
+
     Returns the synced workflow details.
     """
     global client
@@ -239,7 +272,9 @@ async def sync_workflow(
         raise ValueError("Tool not configured")
 
     try:
-        result = await client.sync_workflow(workflow_id, input_component, output_component)
+        result = await client.sync_workflow(
+            workflow_id, source_url, input_component, output_component
+        )
         return json.dumps(result, indent=2)
     except Exception as e:
         if ctx:
@@ -253,25 +288,45 @@ async def list_tasks(
     workflow_id: Optional[str] = None,
     status: Optional[str] = None,
     limit: int = 50,
+    offset: int = 0,
     ctx: Optional[Context] = None,
 ) -> str:
     """
-    List task executions with optional filtering.
-    
+    List task executions with pagination support.
+
     Args:
         workflow_id: Filter by specific workflow (optional)
         status: Filter by status - pending, running, completed, failed (optional)
-        limit: Maximum number of tasks to return (default: 50)
-    
-    Returns a list of task executions with their details.
+        limit: Maximum number of tasks to return (default: 50, max: 100)
+        offset: Number of tasks to skip for pagination (default: 0)
+
+    Returns a paginated response with:
+        - items: List of task executions
+        - total: Total number of tasks matching filters
+        - limit: Items per page
+        - offset: Current offset
+        - has_more: Whether more tasks are available
+
+    Pagination examples:
+        # Get first 50 tasks
+        list_tasks(limit=50, offset=0)
+
+        # Get next 50 tasks
+        list_tasks(limit=50, offset=50)
+
+        # Get specific workflow's tasks, paginated
+        list_tasks(workflow_id="workflow-id", limit=20, offset=0)
+
+        # Get only completed tasks, paginated
+        list_tasks(status="completed", limit=25, offset=0)
     """
     global client
     if not client:
         raise ValueError("Tool not configured")
 
     try:
-        tasks = await client.list_tasks(workflow_id, status, limit)
-        return json.dumps(tasks, indent=2)
+        result = await client.list_tasks(workflow_id, status, limit, offset)
+        return json.dumps(result, indent=2)
     except Exception as e:
         if ctx:
             ctx.error(f"Failed to list tasks: {str(e)}")
@@ -282,10 +337,10 @@ async def list_tasks(
 async def get_task(task_id: str, ctx: Optional[Context] = None) -> str:
     """
     Get detailed information about a specific task execution.
-    
+
     Args:
         task_id: The UUID of the task
-    
+
     Returns task details including input, output, status, and timing.
     """
     global client
@@ -301,6 +356,29 @@ async def get_task(task_id: str, ctx: Optional[Context] = None) -> str:
         raise
 
 
+@mcp.tool()
+async def delete_task(task_id: str, ctx: Optional[Context] = None) -> str:
+    """
+    Delete a task execution.
+
+    Args:
+        task_id: The UUID of the task to delete
+
+    Returns confirmation of deletion.
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        result = await client.delete_task(task_id)
+        return json.dumps(result, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to delete task: {str(e)}")
+        raise
+
+
 # Schedule Management Tools
 @mcp.tool()
 async def list_schedules(
@@ -308,10 +386,10 @@ async def list_schedules(
 ) -> str:
     """
     List all active schedules.
-    
+
     Args:
         workflow_id: Filter by specific workflow (optional)
-    
+
     Returns a list of schedules with their configuration and next run times.
     """
     global client
@@ -337,7 +415,7 @@ async def create_schedule(
 ) -> str:
     """
     Create a new schedule for automated workflow execution.
-    
+
     Args:
         workflow_id: The UUID of the workflow to schedule
         schedule_type: Type of schedule - "interval" or "cron"
@@ -345,7 +423,7 @@ async def create_schedule(
             - For interval: "5m", "1h", "30s", "2d"
             - For cron: "0 9 * * *" (daily at 9 AM), "*/15 * * * *" (every 15 minutes)
         input_value: Optional default input for scheduled runs
-    
+
     Returns the created schedule details.
     """
     global client
@@ -363,14 +441,88 @@ async def create_schedule(
         raise
 
 
+@mcp.tool()
+async def get_schedule(schedule_id: str, ctx: Optional[Context] = None) -> str:
+    """
+    Get detailed information about a specific schedule.
+
+    Args:
+        schedule_id: The UUID of the schedule
+
+    Returns schedule details including configuration and next run time.
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        schedule = await client.get_schedule(schedule_id)
+        return json.dumps(schedule, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to get schedule: {str(e)}")
+        raise
+
+
+@mcp.tool()
+async def update_schedule(
+    schedule_id: str,
+    workflow_id: str,
+    schedule_type: str,
+    schedule_expr: str,
+    input_value: Optional[str] = None,
+    ctx: Optional[Context] = None,
+) -> str:
+    """
+    Update an existing schedule.
+
+    Args:
+        schedule_id: The UUID of the schedule to update
+        workflow_id: The UUID of the workflow (required)
+        schedule_type: Type of schedule - "interval" or "cron" (required)
+        schedule_expr: Schedule expression (required)
+            - For interval: "5m", "1h", "30s", "2d"
+            - For cron: "0 9 * * *" (daily at 9 AM), "*/15 * * * *" (every 15 minutes)
+        input_value: Default input for scheduled runs (optional)
+
+    Returns the updated schedule details.
+
+    Note: The Spark API requires all schedule fields to be provided.
+          Use get_schedule() first to retrieve current values if you only want to change one field.
+
+    Example workflow:
+        1. schedule = get_schedule(schedule_id)
+        2. update_schedule(
+               schedule_id=schedule_id,
+               workflow_id=schedule["workflow_id"],
+               schedule_type=schedule["schedule_type"],
+               schedule_expr="0 10 * * *",  # Change only this
+               input_value=schedule.get("input_value")
+           )
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        result = await client.update_schedule(
+            schedule_id, workflow_id, schedule_type, schedule_expr, input_value
+        )
+        return json.dumps(result, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to update schedule: {str(e)}")
+        raise
+
+
 @mcp.tool()
 async def delete_schedule(schedule_id: str, ctx: Optional[Context] = None) -> str:
     """
     Delete a schedule.
-    
+
     Args:
         schedule_id: The UUID of the schedule to delete
-    
+
     Returns confirmation of deletion.
     """
     global client
@@ -378,7 +530,7 @@ async def delete_schedule(schedule_id: str, ctx: Optional[Context] = None) -> st
         raise ValueError("Tool not configured")
 
     try:
-        result = await client.delete_schedule(schedule_id)
+        await client.delete_schedule(schedule_id)
         return json.dumps({"success": True, "deleted": schedule_id})
     except Exception as e:
         if ctx:
@@ -390,10 +542,10 @@ async def delete_schedule(schedule_id: str, ctx: Optional[Context] = None) -> st
 async def enable_schedule(schedule_id: str, ctx: Optional[Context] = None) -> str:
     """
     Enable a disabled schedule.
-    
+
     Args:
         schedule_id: The UUID of the schedule to enable
-    
+
     Returns the updated schedule details.
     """
     global client
@@ -413,10 +565,10 @@ async def enable_schedule(schedule_id: str, ctx: Optional[Context] = None) -> st
 async def disable_schedule(schedule_id: str, ctx: Optional[Context] = None) -> str:
     """
     Disable an active schedule.
-    
+
     Args:
         schedule_id: The UUID of the schedule to disable
-    
+
     Returns the updated schedule details.
     """
     global client
@@ -434,10 +586,15 @@ async def disable_schedule(schedule_id: str, ctx: Optional[Context] = None) -> s
 
 # Source Management Tools
 @mcp.tool()
-async def list_sources(ctx: Optional[Context] = None) -> str:
+async def list_sources(
+    status: Optional[str] = None, ctx: Optional[Context] = None
+) -> str:
     """
     List all configured workflow sources.
-    
+
+    Args:
+        status: Filter by status - "active" or "inactive" (optional)
+
     Returns a list of sources (AutoMagik Agents, AutoMagik Hive instances).
     """
     global client
@@ -445,7 +602,7 @@ async def list_sources(ctx: Optional[Context] = None) -> str:
         raise ValueError("Tool not configured")
 
     try:
-        sources = await client.list_sources()
+        sources = await client.list_sources(status)
         return json.dumps(sources, indent=2)
     except Exception as e:
         if ctx:
@@ -453,6 +610,29 @@ async def list_sources(ctx: Optional[Context] = None) -> str:
         raise
 
 
+@mcp.tool()
+async def get_source(source_id: str, ctx: Optional[Context] = None) -> str:
+    """
+    Get detailed information about a specific workflow source.
+
+    Args:
+        source_id: The UUID of the source
+
+    Returns source details including configuration and status.
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        source = await client.get_source(source_id)
+        return json.dumps(source, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to get source: {str(e)}")
+        raise
+
+
 @mcp.tool()
 async def add_source(
     name: str,
@@ -463,15 +643,15 @@ async def add_source(
 ) -> str:
     """
     Add a new workflow source.
-    
+
     Args:
         name: Display name for the source
         source_type: Type of source - "automagik-agents", "automagik-hive", or "langflow"
         url: Base URL of the source (e.g., http://localhost:8881)
         api_key: Optional API key for authentication
-    
+
     Returns the created source details.
-    
+
     Example:
         add_source("Local Agents", "automagik-agents", "http://localhost:8881", "namastex888")
     """
@@ -488,14 +668,46 @@ async def add_source(
         raise
 
 
+@mcp.tool()
+async def update_source(
+    source_id: str,
+    name: Optional[str] = None,
+    url: Optional[str] = None,
+    api_key: Optional[str] = None,
+    ctx: Optional[Context] = None,
+) -> str:
+    """
+    Update a workflow source configuration.
+
+    Args:
+        source_id: The UUID of the source to update
+        name: New display name (optional)
+        url: New base URL (optional)
+        api_key: New API key (optional)
+
+    Returns the updated source details.
+    """
+    global client
+    if not client:
+        raise ValueError("Tool not configured")
+
+    try:
+        source = await client.update_source(source_id, name, url, api_key)
+        return json.dumps(source, indent=2)
+    except Exception as e:
+        if ctx:
+            ctx.error(f"Failed to update source: {str(e)}")
+        raise
+
+
 @mcp.tool()
 async def delete_source(source_id: str, ctx: Optional[Context] = None) -> str:
     """
     Delete a workflow source.
-    
+
     Args:
         source_id: The UUID of the source to delete
-    
+
     Returns confirmation of deletion.
     """
     global client
@@ -503,9 +715,9 @@ async def delete_source(source_id: str, ctx: Optional[Context] = None) -> str:
         raise ValueError("Tool not configured")
 
     try:
-        result = await client.delete_source(source_id)
+        await client.delete_source(source_id)
         return json.dumps({"success": True, "deleted": source_id})
     except Exception as e:
         if ctx:
             ctx.error(f"Failed to delete source: {str(e)}")
-        raise
\ No newline at end of file
+        raise
